<?php

namespace Drupal\Tests\domain_access_logo\Functional;

use Drupal\Tests\domain\Traits\DomainTestTrait;
use Drupal\Tests\domain_access_logo\Traits\DomainAccessLogoTestTrait;

/**
 * Tests the domain access logo display.
 *
 * @group domain_access_logo
 */
class DomainAccessLogoDisplayTest extends DomainAccessLogoTestBase {

  use DomainAccessLogoTestTrait;
  use DomainTestTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'block',
    'domain',
    'domain_access_logo',
    'file',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritDoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Add the system branding block to the page.
    $this->drupalPlaceBlock('system_branding_block', [
      'region' => 'header',
      'id' => 'site_branding',
    ]);
  }

  /**
   * Tests the logo display.
   */
  public function testLogoDisplay() {
    $path = $this->configFormPath;
    $field_name = 'edit-example-com-upload';
    $site_logo_xpath = '//div[@id="block-site-branding"]/a/img';

    // Visit the domain access logo administration page as admin.
    $this->drupalLogin($this->adminUser);
    $this->drupalGet($path);

    // Upload an image.
    $image_uri = $this->resourcesPath() . '/' . $this->filename;
    $page = $this->getSession()->getPage();
    $this->assertSession()->fieldExists($field_name);
    $page->attachFileToField($field_name, $image_uri);
    $page->pressButton('Save configuration');

    $this->assertSession()
      ->statusMessageContains('The configuration options have been saved.', 'status');

    $this->drupalGet('<front>');

    // Test that branding element is displayed.
    $this->assertSession()->elementExists('xpath', $site_logo_xpath);

    // Load the file.
    /** @var \Drupal\file\Entity\File $file */
    $file = $this->container->get('entity_type.manager')
      ->getStorage('file')
      ->load(1);

    // Assert that the image is displayed.
    $this->assertSession()
      ->elementAttributeContains('xpath', $site_logo_xpath, 'src', $file->createFileUrl(FALSE));
  }

}
