<?php

namespace Drupal\Tests\domain_access_logo\Traits;

use Drupal\Core\Session\AccountInterface;

/**
 * Contains helper classes for tests to set up various configuration.
 */
trait DomainAccessLogoTestTrait {

  /**
   * The path to the config form.
   *
   * @var string
   */
  protected string $configFormPath = '/admin/config/domain/domain_access_logo';

  /**
   * A file in the resources folder.
   *
   * @var string
   */
  protected string $filename = 'domain-access-logo.png';

  /**
   * A user with full permissions to use the module.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected AccountInterface $adminUser;

  /**
   * A user with administration access but not this module.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected AccountInterface $editorUser;

  /**
   * Create an admin user.
   */
  public function createAdminUser() {
    $this->adminUser = $this->drupalCreateUser([
      'access administration pages',
      'access content',
      'administer domains',
      'administer domains access logos',
      'administer site configuration',
    ]);
  }

  /**
   * Create an editor user.
   */
  public function createEditorUser() {
    $this->editorUser = $this->drupalCreateUser([
      'access administration pages',
      'access content',
      'administer site configuration',
    ]);
  }

  /**
   * Returns the absolute path to the Drupal root.
   *
   * @return string
   *   The absolute path to the directory where Drupal is installed.
   */
  protected function absolute(): string {
    return realpath(getcwd());
  }

  /**
   * Returns the absolute directory path of the Domain Access Logo module.
   *
   * @return string
   *   The absolute path to the Domain Access Logo module.
   */
  protected function absolutePath(): string {
    return $this->absolute() . '/' . $this->getModulePath('domain_access_logo');
  }

  /**
   * Returns the url to the Domain Access Logo fixtures directory.
   *
   * @return string
   *   The url to the Domain Access Logo fixtures directory.
   */
  protected function resourcesUrl(): string {
    return \Drupal::request()->getSchemeAndHttpHost() . '/' . $this->getModulePath('domain_access_logo') . '/tests/fixtures';
  }

  /**
   * Gets the path for the specified module.
   *
   * @param string $module_name
   *   The module name.
   *
   * @return string
   *   The Drupal-root relative path to the module directory.
   *
   * @throws \Drupal\Core\Extension\Exception\UnknownExtensionException
   *   If the module does not exist.
   */
  protected function getModulePath(string $module_name): string {
    return \Drupal::service('extension.list.module')->getPath($module_name);
  }

  /**
   * Returns the absolute directory path of the fixtures folder.
   *
   * @return string
   *   The absolute path to the fixtures folder.
   */
  protected function resourcesPath(): string {
    return $this->absolutePath() . '/tests/fixtures';
  }

}
